# fuelcell

fuelcell is a Python library designed to streamline the process of analyzing data generated from experiments which are commonly used to test electrochemical devices.

## Installation

fuelcell can be installed via the command line using [pip](https://pypi.org) 

``` bash
pip install fuelcell
```

## New in version 1.2.0

* Added docstrings
* Added support for error calculations and error bars
* Updated visualisation methods to improve pass-through to matplotlib
* Bug fixes and minor improvements

## License

[MIT](https://choosealicense.com/licenses/mit/) 